#include <fstream>
#include <string.h>
#include "vertex.h"
#include "panel.h"

void read(const char* s, vertex*& Verts, panel*& Panels)
{
  std::ifstream is(s);
  if (!is) {
    std::cerr << "Error reading '" << s << "'." << std::endl;
    exit(1); 
  }

  unsigned long i;

  unsigned nVerts;
  unsigned nPanels;

  // get numbers of vertices and surfaces
  is >> nVerts;

  // allocate memory
  
  Verts = new vertex[nVerts];
  assert(Verts);

  // get nVerts vertices
  
  for (i=0; i<nVerts; ++i) {
    double x, y;
    is >> x >> y;
    Verts[i].x = x;  // x-coordinate
    Verts[i].y = y;  // y-coordinate
    Verts[i].panels.clear(); // clear the list of panels 
    Verts[i].bp=0; // initialize the boundary point flag
    Verts[i].index=i; // index
  }

  is >> nPanels;
  Panels = new panel[nPanels];
  assert(Panels);

  // get nTets tets

  for (i=0; i<nPanels; ++i) {
    unsigned long j1, k1, k2, k3;
    is >>  j1 >> k1 >> k2 >> k3;
    Panels[i] = panel(&Verts[k1-1], &Verts[k2-1], &Verts[k3-1]);
    Verts[k1-1].panels.push_front(&Panels[i]);
    Verts[k2-1].panels.push_front(&Panels[i]);
    Verts[k3-1].panels.push_front(&Panels[i]);
  }

  unsigned nEdges;
  is >> nEdges;

  for (i=0; i<nEdges; ++i) {
    unsigned long j2, i1, i2;
    is >> j2 >> i1 >> i2;
    Verts[i1-1].bp=1;
    Verts[i2-1].bp=1;
  }

  is.close();
}
